@@ -44,10 +44,10 @@ c32vector? CR%A       h      - 1 3  @     }       g  len
 			 g  fill			  g  filenamef  srfi/srfi-4/gnu.scm
 	9
  			
-  g  nameg  make-c32vector CRBCDEA  h(     ]	4 5	45$  C 	6       g  v
+  g  nameg  make-c32vector CRBCDEA  h(     ]	4 5	45$  C 	6       g  v
 		( g  len		(  g  filenamef  srfi/srfi-4/gnu.scm
 	9
-g  filenamef  g/cygdrive/e/cyg_pub/devel/guile/guile20_T/guile-2.0.14-2.x86_64/src/guile-2.0.14/module/srfi/srfi-4.scm	 	T	 		(  g  nameg  c32vector-length CR     h   p   -  1  3  6 h       g  elts
+g  filenamef  h/cygdrive/d/cyg_pub/devel/guile/guile20/guile2.0-2.0.14-3.x86_64/src/guile-2.0.14/module/srfi/srfi-4.scm	 	T	 		(  g  nameg  c32vector-length CR    h   p   -  1  3  6 h       g  elts
 			  g  filenamef  srfi/srfi-4/gnu.scm
 	9
  			
@@ -82,10 +82,10 @@ c64vector? CR%G       h      - 1 3  @     }       g  len
 			 g  fill			  g  filenamef  srfi/srfi-4/gnu.scm
 	:
  			
-  g  nameg  make-c64vector CRBCDEG  h(     ]	4 5	45$  C 	6       g  v
+  g  nameg  make-c64vector CRBCDEG  h(     ]	4 5	45$  C 	6       g  v
 		( g  len		(  g  filenamef  srfi/srfi-4/gnu.scm
 	:
-g  filenamef  g/cygdrive/e/cyg_pub/devel/guile/guile20_T/guile-2.0.14-2.x86_64/src/guile-2.0.14/module/srfi/srfi-4.scm	 	T	 		(  g  nameg  c64vector-length C R$     h   p   -  1  3  6 h       g  elts
+g  filenamef  h/cygdrive/d/cyg_pub/devel/guile/guile20/guile2.0-2.0.14-3.x86_64/src/guile-2.0.14/module/srfi/srfi-4.scm	 	T	 		(  g  nameg  c64vector-length C R$    h   p   -  1  3  6 h       g  elts
 			  g  filenamef  srfi/srfi-4/gnu.scm
 	:
  			
